==> james-project-3.7.6-source-release.zip: james-project/protocols/netty/src/main/java/org/apache/james/protocols/netty/HandlerConstants.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.protocols.netty;

import org.jboss.netty.channel.ChannelHandler;
import org.jboss.netty.channel.ChannelPipeline;

/**
 * Provide the keys under which the {@link ChannelHandler}'s are stored in the
 * {@link ChannelPipeline}
 */
public interface HandlerConstants {

    String SSL_HANDLER = "sslHandler";

    String GROUP_HANDLER = "groupHandler";

    String CONNECTION_LIMIT_HANDLER = " connectionLimit";

    String CONNECTION_PER_IP_LIMIT_HANDLER = "connectionPerIpLimit";

    String FRAMER = "framer";

    String EXECUTION_HANDLER = "executionHandler";

    String TIMEOUT_HANDLER = "timeoutHandler";

    String CORE_HANDLER = "coreHandler";

    String CHUNK_HANDLER = "chunkHandler";

}

==> james-project-3.9.0-source-release.zip: james-project/protocols/netty/src/main/java/org/apache/james/protocols/netty/HandlerConstants.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.protocols.netty;

import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelPipeline;

/**
 * Provide the keys under which the {@link ChannelHandler}'s are stored in the
 * {@link ChannelPipeline}
 */
public interface HandlerConstants {

    String SSL_HANDLER = "sslHandler";

    String FRAMER = "framer";

    String TIMEOUT_HANDLER = "timeoutHandler";

    String CORE_HANDLER = "coreHandler";

    String CHUNK_HANDLER = "chunkHandler";

    String CONNECTION_LIMIT_PER_IP_HANDLER = "connectionPerIpLimitHandler";

    String CONNECTION_LIMIT_HANDLER = "connectionLimitHandler";

    String PROXY_HANDLER = "proxyHandler";

}
